Ternary Plots
=============

.. toctree::

   reference_simplex_to_profile
   reference_ternary_axes_subplot_poisson
   reference_ternary_figure
   reference_ternary_plot_convergence
   reference_ternary_plot_n_equilibria
   reference_ternary_plot_winners_at_equilibrium
   reference_ternary_plot_winning_frequencies
